Crate state_m

Crate state_m 

Structs

Reader
Data structure to be exposed to do subscription by state change responders.
ReaderEx
Data structure to be exposed to do subscription by state change responders, with the ability to convert the state to another type.
StateMachine
State machine data structure to store sources and handles.

Enums

SourceChangeError

Traits

HasStateHandle
Define action upon state change event.
HasStateMachine
At least you should provide a state machine data structure.
UseStateHandle
Convenient method to do subscription with a state convert function. The trait is auto implemented for types implemented HasStateHandle.
UseStateMachine
Some convenient methods to use state machine. The trait is auto implemented for types implemented HasStateMachine.

Type Aliases

Value