pub struct ReaderEx<S, T> { /* private fields */ }Expand description
Data structure to be exposed to do subscription by state change responders, with the ability to convert the state to another type.
Implementations