pub struct StateMachine<G>{ /* private fields */ }Expand description
State machine data structure to store state sources and handles.
- G - to distinguish different initiators or responders.
Implementations
Sourceimpl<G> StateMachine<G>
impl<G> StateMachine<G>
pub fn new() -> Self
Sourcepub async fn source<S>(&self, tag: G) -> Source<S>where
S: 'static + Clone,
pub async fn source<S>(&self, tag: G) -> Source<S>where
S: 'static + Clone,
Get source from state machine by tag.
Sourcepub async fn source_value<S>(&self, tag: G) -> S
pub async fn source_value<S>(&self, tag: G) -> S
Get current value of source from state machine by tag.
Sourcepub async fn handle<T>(&self, tag: G) -> Handle<T>where
T: 'static + Clone,
pub async fn handle<T>(&self, tag: G) -> Handle<T>where
T: 'static + Clone,
Get handle from state machine.
Sourcepub async fn handle_value<T>(&self, tag: G) -> T
pub async fn handle_value<T>(&self, tag: G) -> T
Get current value of handle from state machine.