Struct Source 

pub struct Source<S> { /* private fields */ }
State source, the initiator of state change.

Implementations

Source

impl<S> Source<S>
where S: 'static + Clone + PartialEq + Send,

pub fn new() -> Self

Create a state source, with broadcast channel capacity of 100.

pub fn create(capacity: usize) -> Self

Create a state source with custom broadcast channel capacity.

  • capacity: broadcast channel capacity
pub fn reader(&self) -> Reader<S, S>

Get reader of state source, can be subscribed by responders.

pub fn reader_with<T>( &self, func: Arc<dyn Fn(S) -> Pin<Box<dyn Future<Output = T> + Send>> + Send + Sync>, ) -> Reader<S, T>

Get reader of state source, can be subscribed by responders.

pub async fn num_of_subs(&self) -> usize

Num of subscriptions.

pub async fn value(&self) -> Option<S>

Get current value of state source.

pub async fn change(&self, s: S) -> Result<(), SourceChangeError>

Change state of source.

pub async fn wait_change(&self, s: S) -> Result<(), SourceChangeError>

Change state of source, and wait responders to finish actions upon the change event.

pub async fn modify( &self, func: impl Fn(S) -> S + 'static, ) -> Result<(), SourceChangeError>

Change state of source by modifying it with a func.

pub async fn wait_modify( &self, func: impl Fn(S) -> S + 'static, ) -> Result<(), SourceChangeError>

Change state of source by modifying it with a func, and wait responders to finish actions upon the change event.

pub async fn touch(&self) -> Result<(), SourceChangeError>

Create a change event without changing state of source really.