pub struct StateMachine<Tag>{ /* private fields */ }Expand description
State machine data structure to store state sources and handles.
Implementations
Sourceimpl<Tag> StateMachine<Tag>
impl<Tag> StateMachine<Tag>
pub fn new() -> Self
Sourcepub async fn source<S>(&self, tag: Tag) -> Source<S>where
S: 'static + Clone,
pub async fn source<S>(&self, tag: Tag) -> Source<S>where
S: 'static + Clone,
Get source from state machine by tag.
Sourcepub async fn source_value<S>(&self, tag: Tag) -> Option<S>
pub async fn source_value<S>(&self, tag: Tag) -> Option<S>
Get current value of source from state machine by tag.
Sourcepub async fn handle<T>(&self, tag: Tag) -> Handle<T>where
T: 'static + Clone,
pub async fn handle<T>(&self, tag: Tag) -> Handle<T>where
T: 'static + Clone,
Get handle from state machine.
Sourcepub async fn handle_value<T>(&self, tag: Tag) -> Option<T>
pub async fn handle_value<T>(&self, tag: Tag) -> Option<T>
Get current value of handle from state machine.